@@ -18,7 +18,7 @@
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.22 2002/06/09 19:02:14 nmav Exp $ */
+/* $Id: extra.c,v 1.24 2002/10/02 07:26:20 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -44,7 +44,7 @@
 #endif
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.22 2002/06/09 19:02:14 nmav Exp $";
+    "$Id: extra.c,v 1.24 2002/10/02 07:26:20 nmav Exp $";
 
 #ifndef NO_GETPASS
 	#define FREE_STR(x) \
@@ -141,27 +141,19 @@ char *get_password( int mode, unsigned int *len)
 }
 
 
-
-#ifdef HAVE_STAT
-
 int check_file(char *filename)
 {
-	struct stat ostat;
-
-	if (stat(filename, &ostat) == 0) {
-		return 1;	/* exists */
-	} else {
-		return 0;	/* no */
-	}
-
+FILE* fd;
 
+	fd = fopen( filename, "r");
+	if ( fd == NULL) return 0; /* does not exist  */
+	
+	fclose( fd);
+	
+	return 1; /* ok, it exists */
 }
 
 
-#endif
-
-
-
 void read_until_null(char *pointer, FILE * fstream)
 {
 	int i;
@@ -417,10 +409,10 @@ int write_iv(FILE * filedes, void *IV, int ivsize)
 void copyDate(char *srcName, char *dstName)
 {
 	int retVal;
-	struct stat statBuf;
+	stat_st statBuf;
 	struct utimbuf uTimBuf;
 
-	retVal = stat(srcName, &statBuf);
+	retVal = stat64(srcName, &statBuf);
 	if (retVal == -1)
 		perror("stat");
 
@@ -436,13 +428,13 @@ void copyDate(char *srcName, char *dstName)
 
 int is_normal_file(char *filename)
 {
-	struct stat statBuf;
+	stat_st statBuf;
 
 #ifdef HAVE_LSTAT		/* Do not treat symlinks as regular files */
-	if (lstat(filename, &statBuf) != 0)
+	if (lstat64(filename, &statBuf) != 0)
 		return FALSE;
 #else
-	if (stat(filename, &statBuf) != 0)
+	if (stat64(filename, &statBuf) != 0)
 		return FALSE;
 #endif
 
@@ -627,7 +619,11 @@ unsigned char x;
 	} else {
 		FILE* fd;
 		
-		fd = fopen( file, "rb");
+		fd = fopen64( file, "rb");
+		if (fd == NULL) {
+		   perror("fopen64");
+		   err_quit(_("Could not open file\n"));
+		}
 		x = getc( fd);
 		fclose(fd);
 	}
